import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl =
  "https://gist.githubusercontent.com/MekaNavyasri/ff2889eca291f60eb3bc7b8bd987e8bd/raw/27586acd82f54b74704bc7cf73dad8131971f721/ICE-6"
const width = 960;
const height = 500;
const margin = { top: 20, right: 20, bottom: 50, left: 200 };


const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.ANNUAL = +d['ANNUAL'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 12));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;
 
  const filteredData = data.filter(d => d.STATE_UT_NAME === 'ARUNACHAL PRADESH');
  const yScale = scaleBand()
    .domain(filteredData.map(d => d.DISTRICT))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.ANNUAL)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="red" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.DISTRICT}
            x={0}
            y={yScale(d.DISTRICT)}
            width={xScale(d.ANNUAL)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);